﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using System.Speech.Recognition;

namespace WpfApplication1
{
    /// <summary>
    /// MainWindow.xaml の相互作用ロジック
    /// </summary>
    public partial class MainWindow : Window
    {

        SpeechRecognitionEngine recogEngine;

        public MainWindow()
        {
            InitializeComponent();

            recogEngine = new SpeechRecognitionEngine();

            // 音声認識が認識処理を終えたときのイベントハンドラを設定する。
            recogEngine.SpeechRecognized += recogEngine_SpeechRecognized;

            // 音声認識が推定処理を終えたときのイベントハンドラを設定する。
            recogEngine.SpeechHypothesized += recogEngine_SpeechHypothesized;

            // SystemSpeech を利用したディクテーションを行う場合には、
            // DictationGrammar (ディクテーション用の辞書) を追加する。
            recogEngine.LoadGrammar(new DictationGrammar());
            
            // 実行環境の標準の入力を音声認識エンジンの入力とする。
            recogEngine.SetInputToDefaultAudioDevice();
            
            // 非同期の認識を継続して実行するようにして音声認識を開始する。
            recogEngine.RecognizeAsync(RecognizeMode.Multiple);
        }

        // 推定時の処理
        void recogEngine_SpeechHypothesized(object sender, SpeechHypothesizedEventArgs e)
        {
            this.textBox.Text = "○" + e.Result.Text + "("+ e.Result.Confidence + ")\n" + this.textBox.Text;
        }

        // 認識時の処理
        void recogEngine_SpeechRecognized(object sender, SpeechRecognizedEventArgs e)
        {
            this.textBox.Text = "●" + e.Result.Text + "(" + e.Result.Confidence + ")\n" + this.textBox.Text;
        }

        protected override void OnClosed(EventArgs e)
        {
            base.OnClosed(e);

            // 終了時には破棄する。
            recogEngine.Dispose();
        }
    }
}